#! /usr/bin/env python
# render.py


"""Sample language

render
    -safe 80%
    -in background.avi -scale 720x480
    -in logo.png -scale 80x60 -align topright
    -in title1.avi -trim 5s -scale 120x80 -shadow 50% -align topleft
    -in title2.avi -trim 5s -scale 120x80 -shadow 50% -align left
    -in title3.avi -trim 5s -scale 120x80 -shadow 50% -align bottomleft
    -out finalmenu.mpg

Alternatively:

Render "Final menu"
    -clips Background, Logo, Title1, Title2, Title3
Clip "Background"
    -in background.avi -scale 720x480
Clip "Logo"
    -in logo.png -scale 80x60 -align topright
Clip "Title1"
    -in title1.avi -trim 5s -scale 120x80 -shadow 50% -align topleft
...

Support cropping/shrinking to a given aspect ratio

Expectation:
    Each -in loads a new buffer; here, five buffers are created. The first
    buffer determines the background canvas size, and each additional buffer
    is aligned with respect to that canvas (and safe area).
    
    Input files may be videos or still images; either may be trimmed to the
    desired size.
    
    Any effects after -in (and before the next -in) apply to the current
    buffer. Some effects (scaling) can be performed during frame-dump, others
    (alignment, shadow) during the rendering phase.

Execution:
    Each -in file ("clip") is rendered, frame-by-frame, to jpg (optionally png)
    files, at the given scaling (and trimmed to the given length). A Python
    object (VideoClip) stores filename & all other attributes, along with a list
    of filenames for the frames once rendered.

"""

# From libtovid
import VideoUtils
from opts import Option
from mvg import MVG

class VideoClip:
    """A segment of video, along with related attributes."""
    optdefs = {
        'in': Option('in', 'FILE', None,
            """Get video content from the given file (video or image)."""),
        'scale': Option('scale', 'WxH', '720x480',
            """Scale the clip to the given size in pixels."""),
        'align': Option('align', '[northwest|north|northeast]', 'northwest',
            """Alignment of the clip against any given background."""),
        'trim': Option('length', 'NUM', 5,
            """Make clip NUM seconds in length.""")
    }
    def rip_frames(self, format='jpg'):
        """Extract jpg or png frames from the current video."""
        VideoUtils.video_to_images(self['in'], 0, self['trim'], (300,200))


